@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed.c,v 1.68 2005/11/01 12:46:06 chpe Exp $
+ *  $Id: ephy-embed.c,v 1.71 2006/01/08 22:28:09 jframeau Exp $
  */
 
 #include "config.h"
@@ -386,6 +386,22 @@ ephy_embed_base_init (gpointer g_class)
 			      ephy_marshal_BOOLEAN__VOID,
 			      G_TYPE_BOOLEAN,
 			      0);
+/**
+ * EphyEmbed::content-blocked:
+ * @embed:
+ * @uri: blocked URI 
+ *
+ * The ::content-blocked signal is emitted when an url has been blocked.
+ **/
+		g_signal_new ("content-blocked",
+			      EPHY_TYPE_EMBED,
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (EphyEmbedIface, content_blocked),
+			      NULL, NULL,
+			      g_cclosure_marshal_VOID__STRING,
+			      G_TYPE_NONE,
+			      1,
+			      G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE);
 
 		initialized = TRUE;
 	}
@@ -644,6 +660,59 @@ ephy_embed_get_zoom (EphyEmbed *embed)
 	return iface->get_zoom (embed);
 }
 
+/**
+ * ephy_embed_scroll:
+ * @embed: an #EphyEmbed
+ * @num_lines: The number of lines to scroll by
+ *
+ * Scrolls the view by lines. Positive numbers scroll down, negative
+ * numbers scroll up
+ *
+ **/
+void
+ephy_embed_scroll (EphyEmbed *embed,
+		   int num_lines)
+{
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->scroll_lines (embed, num_lines);
+}
+
+/**
+ * ephy_embed_page_scroll:
+ * @embed: an #EphyEmbed
+ * @num_lines: The number of pages to scroll by
+ *
+ * Scrolls the view by pages. Positive numbers scroll down, negative
+ * numbers scroll up
+ *
+ **/
+void
+ephy_embed_page_scroll (EphyEmbed *embed,
+			int num_pages)
+{
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->scroll_pages (embed, num_pages);
+}
+
+/**
+ * ephy_embed_scroll_pixels:
+ * @embed: an #EphyEmbed
+ * @dx: the number of pixels to scroll in X direction
+ * @dy: the number of pixels to scroll in Y direction
+ *
+ * Scrolls the view by pixels. Positive numbers scroll down resp. right,
+ * negative numbers scroll up resp. left.
+ *
+ **/
+void
+ephy_embed_scroll_pixels (EphyEmbed *embed,
+			  int dx,
+			  int dy)
+{
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->scroll_pixels (embed, dx, dy);
+}
+
 /**
  * ephy_embed_shistory_n_items:
  * @embed: an #EphyEmbed
