@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyFind.cpp,v 1.8 2006/07/06 19:00:32 chpe Exp $
+ *  $Id: EphyFind.cpp,v 1.9 2006/08/19 13:56:41 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -206,19 +206,15 @@ EphyFind::FindAgain (PRBool aForward)
 
   nsresult rv;
   PRUint16 found = nsITypeAheadFind::FIND_NOTFOUND;
+#ifdef HAVE_GECKO_1_9
+  rv = mFinder->FindAgain (aForward, mHasFocus, &found);
+#else
   if (aForward) {
-#ifdef HAVE_GECKO_1_9
-    rv = mFinder->FindNext (mHasFocus, &found);
-#else
     rv = mFinder->FindNext (&found);
-#endif
   } else {
-#ifdef HAVE_GECKO_1_9
-    rv = mFinder->FindPrevious (mHasFocus, &found);
-#else
     rv = mFinder->FindPrevious (&found);
-#endif
   }
+#endif
 
   return (EphyEmbedFindResult) found;
 }
