@@ -15,22 +15,23 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyFind.h,v 1.4 2005/12/04 21:52:04 chpe Exp $
+ *  $Id: EphyFind.h,v 1.6 2006/07/06 19:00:32 chpe Exp $
  */
 
 #ifndef TYPEAHEADFIND_H
 #define TYPEAHEADFIND_H
 
-#include "ephy-embed.h"
-#include "ephy-embed-find.h"
-
-#include <nsCOMPtr.h>
 #include <gdk/gdktypes.h>
 
 class nsITypeAheadFind;
 class nsIWebBrowser;
 class nsIWebBrowserFind;
 
+#include <nsCOMPtr.h>
+
+#include "ephy-embed.h"
+#include "ephy-embed-find.h"
+
 class EphyFind
 {
   public:
@@ -51,12 +52,9 @@ class EphyFind
 
     nsCOMPtr<nsIWebBrowser> mWebBrowser;
 
-#ifdef HAVE_TYPEAHEADFIND
     nsCOMPtr<nsITypeAheadFind> mFinder;
-    PRBool mAttention;
-#else
-    nsCOMPtr<nsIWebBrowserFind> mFinder;
-#endif
+    PRPackedBool mAttention;
+    PRPackedBool mHasFocus;
 };
 
 #endif /* !TYPEAHEADFIND_H */
