@@ -16,15 +16,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  * 
- *  $Id: EphySidebar.h,v 1.2 2005/05/01 14:04:24 chpe Exp $
+ *  $Id: EphySidebar.h,v 1.3 2006/05/10 18:07:00 chpe Exp $
  */
 
 #ifndef EPHY_SIDEBAR_H
 #define EPHY_SIDEBAR_H
 
 #include <nsISidebar.h>
-#include <nsIClassInfo.h>
-#include <nsError.h>
 
 #define EPHY_SIDEBAR_CLASSNAME \
  "Epiphany's Sidebar Implementation"
