@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: FilePicker.cpp,v 1.57 2006/05/15 18:12:31 chpe Exp $
+ *  $Id: FilePicker.cpp,v 1.58 2006/07/06 13:22:34 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -44,6 +44,7 @@
 #include "ephy-prefs.h"
 
 #include "AutoJSContextStack.h"
+#include "AutoWindowModalState.h"
 #include "EphyUtils.h"
 
 #include "FilePicker.h"
@@ -77,6 +78,8 @@ NS_IMETHODIMP GFilePicker::Init(nsIDOMWindowInternal *parent, const PRUnichar *t
 {
 	LOG ("GFilePicker::Init");
 
+	mParent = do_QueryInterface (parent);
+
 	GtkWidget *gtkparent = EphyUtils::FindGtkParent (parent);
 #if defined(MOZ_NSIFILEPICKER_NSASTRING_)
 	NS_ENSURE_TRUE (gtkparent, NS_ERROR_FAILURE);
@@ -431,6 +434,9 @@ NS_IMETHODIMP GFilePicker::Show(PRInt16 *_retval)
 	rv = stack.Init ();
 	if (NS_FAILED (rv)) return rv;
 
+	AutoWindowModalState (mParent);
+	mParent = nsnull;
+
 	LOG ("GFilePicker::Show");
 
 	gtk_window_set_modal (GTK_WINDOW (mDialog), TRUE);
