@@ -6,7 +6,7 @@
 
 G_BEGIN_DECLS
 
-/* VOID:OBJECT,OBJECT (./eggmarshalers.list:1) */
+/* VOID:OBJECT,OBJECT (../../../lib/egg/eggmarshalers.list:1) */
 extern void _egg_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -14,7 +14,7 @@ extern void _egg_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
 
-/* VOID:OBJECT,STRING,LONG,LONG (./eggmarshalers.list:2) */
+/* VOID:OBJECT,STRING,LONG,LONG (../../../lib/egg/eggmarshalers.list:2) */
 extern void _egg_marshal_VOID__OBJECT_STRING_LONG_LONG (GClosure     *closure,
                                                         GValue       *return_value,
                                                         guint         n_param_values,
@@ -22,7 +22,7 @@ extern void _egg_marshal_VOID__OBJECT_STRING_LONG_LONG (GClosure     *closure,
                                                         gpointer      invocation_hint,
                                                         gpointer      marshal_data);
 
-/* VOID:OBJECT,LONG (./eggmarshalers.list:3) */
+/* VOID:OBJECT,LONG (../../../lib/egg/eggmarshalers.list:3) */
 extern void _egg_marshal_VOID__OBJECT_LONG (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -30,7 +30,7 @@ extern void _egg_marshal_VOID__OBJECT_LONG (GClosure     *closure,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
 
-/* VOID:OBJECT,STRING,STRING (./eggmarshalers.list:4) */
+/* VOID:OBJECT,STRING,STRING (../../../lib/egg/eggmarshalers.list:4) */
 extern void _egg_marshal_VOID__OBJECT_STRING_STRING (GClosure     *closure,
                                                      GValue       *return_value,
                                                      guint         n_param_values,
@@ -38,7 +38,7 @@ extern void _egg_marshal_VOID__OBJECT_STRING_STRING (GClosure     *closure,
                                                      gpointer      invocation_hint,
                                                      gpointer      marshal_data);
 
-/* VOID:UINT,UINT (./eggmarshalers.list:5) */
+/* VOID:UINT,UINT (../../../lib/egg/eggmarshalers.list:5) */
 extern void _egg_marshal_VOID__UINT_UINT (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -46,7 +46,7 @@ extern void _egg_marshal_VOID__UINT_UINT (GClosure     *closure,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);
 
-/* BOOLEAN:INT (./eggmarshalers.list:6) */
+/* BOOLEAN:INT (../../../lib/egg/eggmarshalers.list:6) */
 extern void _egg_marshal_BOOLEAN__INT (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
@@ -54,7 +54,7 @@ extern void _egg_marshal_BOOLEAN__INT (GClosure     *closure,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);
 
-/* BOOLEAN:ENUM (./eggmarshalers.list:7) */
+/* BOOLEAN:ENUM (../../../lib/egg/eggmarshalers.list:7) */
 extern void _egg_marshal_BOOLEAN__ENUM (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
@@ -62,7 +62,7 @@ extern void _egg_marshal_BOOLEAN__ENUM (GClosure     *closure,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);
 
-/* BOOLEAN:VOID (./eggmarshalers.list:8) */
+/* BOOLEAN:VOID (../../../lib/egg/eggmarshalers.list:8) */
 extern void _egg_marshal_BOOLEAN__VOID (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
@@ -70,7 +70,7 @@ extern void _egg_marshal_BOOLEAN__VOID (GClosure     *closure,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);
 
-/* OBJECT:VOID (./eggmarshalers.list:9) */
+/* OBJECT:VOID (../../../lib/egg/eggmarshalers.list:9) */
 extern void _egg_marshal_OBJECT__VOID (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
@@ -78,10 +78,10 @@ extern void _egg_marshal_OBJECT__VOID (GClosure     *closure,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);
 
-/* VOID:VOID (./eggmarshalers.list:10) */
+/* VOID:VOID (../../../lib/egg/eggmarshalers.list:10) */
 #define _egg_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID
 
-/* VOID:INT,INT (./eggmarshalers.list:11) */
+/* VOID:INT,INT (../../../lib/egg/eggmarshalers.list:11) */
 extern void _egg_marshal_VOID__INT_INT (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
@@ -89,12 +89,12 @@ extern void _egg_marshal_VOID__INT_INT (GClosure     *closure,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);
 
-/* VOID:UINT,UINT (./eggmarshalers.list:12) */
+/* VOID:UINT,UINT (../../../lib/egg/eggmarshalers.list:12) */
 
-/* VOID:BOOLEAN (./eggmarshalers.list:13) */
+/* VOID:BOOLEAN (../../../lib/egg/eggmarshalers.list:13) */
 #define _egg_marshal_VOID__BOOLEAN	g_cclosure_marshal_VOID__BOOLEAN
 
-/* VOID:OBJECT,ENUM,BOXED (./eggmarshalers.list:14) */
+/* VOID:OBJECT,ENUM,BOXED (../../../lib/egg/eggmarshalers.list:14) */
 extern void _egg_marshal_VOID__OBJECT_ENUM_BOXED (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
@@ -102,10 +102,10 @@ extern void _egg_marshal_VOID__OBJECT_ENUM_BOXED (GClosure     *closure,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);
 
-/* VOID:BOXED (./eggmarshalers.list:15) */
+/* VOID:BOXED (../../../lib/egg/eggmarshalers.list:15) */
 #define _egg_marshal_VOID__BOXED	g_cclosure_marshal_VOID__BOXED
 
-/* BOOLEAN:BOOLEAN (./eggmarshalers.list:16) */
+/* BOOLEAN:BOOLEAN (../../../lib/egg/eggmarshalers.list:16) */
 extern void _egg_marshal_BOOLEAN__BOOLEAN (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -113,7 +113,7 @@ extern void _egg_marshal_BOOLEAN__BOOLEAN (GClosure     *closure,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);
 
-/* BOOLEAN:OBJECT,STRING,STRING (./eggmarshalers.list:17) */
+/* BOOLEAN:OBJECT,STRING,STRING (../../../lib/egg/eggmarshalers.list:17) */
 extern void _egg_marshal_BOOLEAN__OBJECT_STRING_STRING (GClosure     *closure,
                                                         GValue       *return_value,
                                                         guint         n_param_values,
@@ -121,7 +121,15 @@ extern void _egg_marshal_BOOLEAN__OBJECT_STRING_STRING (GClosure     *closure,
                                                         gpointer      invocation_hint,
                                                         gpointer      marshal_data);
 
-/* STRING:POINTER (./eggmarshalers.list:18) */
+/* BOOLEAN:ENUM,INT (../../../lib/egg/eggmarshalers.list:18) */
+extern void _egg_marshal_BOOLEAN__ENUM_INT (GClosure     *closure,
+                                            GValue       *return_value,
+                                            guint         n_param_values,
+                                            const GValue *param_values,
+                                            gpointer      invocation_hint,
+                                            gpointer      marshal_data);
+
+/* STRING:POINTER (../../../lib/egg/eggmarshalers.list:19) */
 extern void _egg_marshal_STRING__POINTER (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -129,7 +137,7 @@ extern void _egg_marshal_STRING__POINTER (GClosure     *closure,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);
 
-/* STRING:STRING,STRING (./eggmarshalers.list:19) */
+/* STRING:STRING,STRING (../../../lib/egg/eggmarshalers.list:20) */
 extern void _egg_marshal_STRING__STRING_STRING (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
