@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-file-helpers.c,v 1.47.2.1 2006/05/29 19:49:44 chpe Exp $
+ *  $Id: ephy-file-helpers.c,v 1.49 2006/08/09 20:08:29 jframeau Exp $
  */
 
 #include "config.h"
@@ -925,6 +925,7 @@ launch_desktop_item (const char *desktop_file,
 
 gboolean
 ephy_file_launch_desktop_file (const char *filename,
+			       const char *parameter,
 			       guint32 user_time)
 {
 	GError *error = NULL;
@@ -947,7 +948,7 @@ ephy_file_launch_desktop_file (const char *filename,
 
 	if (path != NULL)
 	{
-		ret = launch_desktop_item (path, NULL, user_time, &error);
+		ret = launch_desktop_item (path, parameter, user_time, &error);
 
 		if (ret == -1 || error != NULL)
 		{
