@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-node.h,v 1.22 2005/04/08 13:26:24 chpe Exp $
+ *  $Id: ephy-node.h,v 1.24 2006/05/22 20:40:51 jframeau Exp $
  */
 
 #ifndef EPHY_NODE_H
@@ -89,16 +89,34 @@ gboolean    ephy_node_get_property          (EphyNode *node,
 
 const char *ephy_node_get_property_string   (EphyNode *node,
 					     guint property_id);
+void        ephy_node_set_property_string   (EphyNode *node,
+					     guint property_id,
+					     const char *value);
 gboolean    ephy_node_get_property_boolean  (EphyNode *node,
 					     guint property_id);
+void        ephy_node_set_property_boolean  (EphyNode *node,
+					     guint property_id,
+					     gboolean value);
 long        ephy_node_get_property_long     (EphyNode *node,
 					     guint property_id);
+void        ephy_node_set_property_long     (EphyNode *node,
+					     guint property_id,
+					     long value);
 int         ephy_node_get_property_int      (EphyNode *node,
 					     guint property_id);
+void        ephy_node_set_property_int      (EphyNode *node,
+					     guint property_id,
+					     int value);
 double      ephy_node_get_property_double   (EphyNode *node,
 					     guint property_id);
+void        ephy_node_set_property_double   (EphyNode *node,
+					     guint property_id,
+					     double value);
 float       ephy_node_get_property_float    (EphyNode *node,
 					     guint property_id);
+void        ephy_node_set_property_float    (EphyNode *node,
+					     guint property_id,
+					     float value);
 EphyNode   *ephy_node_get_property_node     (EphyNode *node,
 					     guint property_id);
 
@@ -129,6 +147,12 @@ EphyNode     *ephy_node_get_next_child      (EphyNode *node,
 					     EphyNode *child);
 EphyNode     *ephy_node_get_previous_child  (EphyNode *node,
 					     EphyNode *child);
+void	      ephy_node_set_is_drag_source  (EphyNode *node,
+					     gboolean allow);
+gboolean      ephy_node_get_is_drag_source  (EphyNode *node);
+void	      ephy_node_set_is_drag_dest    (EphyNode *node,
+					     gboolean allow);
+gboolean      ephy_node_get_is_drag_dest    (EphyNode *node);
 
 G_END_DECLS
 
