@@ -15,27 +15,39 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-string.h,v 1.10 2004/10/22 21:43:02 chpe Exp $
+ *  $Id: ephy-string.h,v 1.16 2006/08/05 15:06:23 chpe Exp $
  */
 
 #ifndef EPHY_STRING_H
 #define EPHY_STRING_H
 
 #include <glib.h>
+#include <glib-object.h>
 
 G_BEGIN_DECLS
 
-gboolean	 ephy_string_to_int			(const char *string,
-							 gulong *integer);
+gboolean  ephy_string_to_int	(const char *string,
+				 gulong *integer);
 
-char		*ephy_string_blank_chr			(char *source);
+char	 *ephy_string_blank_chr	(char *source);
 
-char		*ephy_string_shorten			(const char *str,
-							 int target_length);
+char	 *ephy_string_shorten	(char *str,
+				 gsize target_length);
 
-char		*ephy_string_elide_underscores		(const char *original);
+char	 *ephy_string_collate_key_for_domain	(const char *host,
+						 gssize len);
 
-char            *ephy_string_double_underscores         (const char *string);
+guint	  ephy_string_flags_from_string	(GType type,
+					 const char *flags_string);
+
+char     *ephy_string_flags_to_string	(GType type,
+					 guint flags_value);
+
+guint	  ephy_string_enum_from_string	(GType type,
+					 const char *enum_string);
+
+char     *ephy_string_enum_to_string	(GType type,
+					 guint enum_value);
 
 G_END_DECLS
 
