@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-bookmark-action.c,v 1.74 2006/01/29 14:28:34 crispin Exp $
+ *  $Id: ephy-bookmark-action.c,v 1.80 2006/07/01 13:23:49 chpe Exp $
  */
 
 #include "config.h"
@@ -31,6 +31,7 @@
 #include "ephy-shell.h"
 #include "ephy-gui.h"
 #include "ephy-debug.h"
+#include "ephy-dnd.h"
 
 #include <glib/gi18n.h>
 #include <gtk/gtkwidget.h>
@@ -49,14 +50,15 @@
 
 #include <string.h>
 
+static const GtkTargetEntry drag_types[] = {
+  {EPHY_DND_URL_TYPE, 0, 0},
+};
+
 /* FIXME tweak this, or make it configurable? (bug 148093) */
 #define ENTRY_WIDTH_CHARS	12
 #define TOOLITEM_WIDTH_CHARS	20
 #define LABEL_WIDTH_CHARS       32
 
-static void ephy_bookmark_action_init       (EphyBookmarkAction *action);
-static void ephy_bookmark_action_class_init (EphyBookmarkActionClass *class);
-
 #define EPHY_BOOKMARK_ACTION_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_BOOKMARK_ACTION, EphyBookmarkActionPrivate))
 
 struct _EphyBookmarkActionPrivate
@@ -76,35 +78,7 @@ enum
 	PROP_ICON
 };
 
-static GObjectClass *parent_class = NULL;
-
-GType
-ephy_bookmark_action_get_type (void)
-{
-	static GType type = 0;
-
-	if (G_UNLIKELY (type == 0))
-	{
-		static const GTypeInfo type_info =
-		{
-			sizeof (EphyBookmarkActionClass),
-			(GBaseInitFunc) NULL,
-			(GBaseFinalizeFunc) NULL,
-			(GClassInitFunc) ephy_bookmark_action_class_init,
-			(GClassFinalizeFunc) NULL,
-			NULL,
-			sizeof (EphyBookmarkAction),
-			0, /* n_preallocs */
-			(GInstanceInitFunc) ephy_bookmark_action_init,
-		};
-
-		type = g_type_register_static (EPHY_TYPE_LINK_ACTION,
-					       "EphyBookmarkAction",
-					       &type_info, 0);
-	}
-
-	return type;
-}
+static GObjectClass *parent_class;
 
 static GtkWidget *
 create_tool_item (GtkAction *action)
@@ -152,15 +126,17 @@ create_tool_item (GtkAction *action)
 }
 
 static void
-ephy_bookmark_action_sync_smart_url (GtkAction *gaction, GParamSpec *pspec, GtkWidget *proxy)
+ephy_bookmark_action_sync_smart_url (GtkAction *gaction,
+				     GParamSpec *pspec,
+				     GtkWidget *proxy)
 {
 	if (GTK_IS_TOOL_ITEM (proxy))
 	{
 		EphyBookmarkAction *action = EPHY_BOOKMARK_ACTION (gaction);
 		EphyBookmarkActionPrivate *priv = action->priv;
 		gboolean is_smart_url = priv->smart_url;
-		gboolean has_icon = (gboolean) ephy_node_get_property_string
-		  (priv->node, EPHY_NODE_BMK_PROP_ICON);		
+		gboolean has_icon = ephy_node_get_property_string
+		  (priv->node, EPHY_NODE_BMK_PROP_ICON) != NULL;
 		GtkWidget *entry, *icon;
 		guint width;
 
@@ -198,7 +174,9 @@ favicon_cache_changed_cb (EphyFaviconCache *cache,
 }
 
 static void
-ephy_bookmark_action_sync_icon (GtkAction *action, GParamSpec *pspec, GtkWidget *proxy)
+ephy_bookmark_action_sync_icon (GtkAction *action,
+				GParamSpec *pspec,
+				GtkWidget *proxy)
 {
 	EphyBookmarkAction *bma = EPHY_BOOKMARK_ACTION (action);
 	const char *icon_location;
@@ -209,9 +187,9 @@ ephy_bookmark_action_sync_icon (GtkAction *action, GParamSpec *pspec, GtkWidget
 
 	icon_location = ephy_node_get_property_string (bma->priv->node,
 						       EPHY_NODE_BMK_PROP_ICON);
-	
+
 	cache = EPHY_FAVICON_CACHE (ephy_embed_shell_get_favicon_cache
-		(EPHY_EMBED_SHELL (ephy_shell)));
+		(ephy_embed_shell_get_default ()));
 
 	if (icon_location && *icon_location)
 	{
@@ -414,9 +392,77 @@ button_release_cb (GtkWidget *widget,
 	return FALSE;
 }
 
+static void
+drag_data_get_cb (GtkWidget          *widget,
+		  GdkDragContext     *context,
+		  GtkSelectionData   *selection_data,
+		  guint               info,
+		  guint32             time,
+		  GtkAction          *action)
+{
+	EphyNode *node = ephy_bookmark_action_get_bookmark (EPHY_BOOKMARK_ACTION (action));
+	const char *location = ephy_node_get_property_string (node, EPHY_NODE_BMK_PROP_LOCATION);
+
+	g_return_if_fail (location != NULL);
+
+	gtk_selection_data_set (selection_data, selection_data->target, 8, (unsigned char *)location, strlen (location));
+}
 
 static void
-connect_proxy (GtkAction *action, GtkWidget *proxy)
+toolbar_reconfigured_cb (GtkToolItem *toolitem,
+			 GtkAction *action)
+{
+	ephy_bookmark_action_sync_icon (action, NULL, GTK_WIDGET (toolitem));
+}
+
+
+static gboolean
+set_tooltip_cb (GtkToolItem *toolitem,
+		GtkTooltips *tooltips,
+		gchar *tip_text,
+		gchar *tip_private,
+		GtkAction *action)
+{
+	EphyBookmarks *bookmarks;
+	EphyNode *node;
+	GtkWidget *button;
+	
+	const char *title, *location;
+	char *tooltip;
+	
+	node = ephy_bookmark_action_get_bookmark (EPHY_BOOKMARK_ACTION (action));
+	bookmarks = ephy_shell_get_bookmarks (ephy_shell_get_default ());
+	title = ephy_node_get_property_string (node, EPHY_NODE_BMK_PROP_TITLE);
+	location = ephy_node_get_property_string (node, EPHY_NODE_BMK_PROP_LOCATION);
+	tooltip = NULL;
+	
+	if (strstr (location, "%s") != NULL)
+	{
+		GnomeVFSURI *uri = gnome_vfs_uri_new (location);
+		if (uri != NULL)
+		{
+			tooltip = g_strconcat
+			  (title, "\n", gnome_vfs_uri_get_scheme (uri),
+			   "://", gnome_vfs_uri_get_host_name (uri), NULL);
+			gnome_vfs_uri_unref (uri);
+		}
+	}
+	if (tooltip == NULL)
+	{
+		tooltip = g_strconcat (title, "\n", location, NULL);
+	}
+	
+	button = g_object_get_data (G_OBJECT (toolitem), "button");
+	gtk_tooltips_set_tip (tooltips, button, tooltip, NULL);
+	g_free (tooltip);
+	
+	return TRUE;
+}
+
+
+static void
+connect_proxy (GtkAction *action,
+	       GtkWidget *proxy)
 {
 	GtkWidget *button, *entry;
 
@@ -437,6 +483,11 @@ connect_proxy (GtkAction *action, GtkWidget *proxy)
 		ephy_bookmark_action_sync_label (action, NULL, proxy);
 		g_signal_connect_object (action, "notify::label",
 					 G_CALLBACK (ephy_bookmark_action_sync_label), proxy, 0);
+		
+		g_signal_connect (proxy, "toolbar-reconfigured",
+				  G_CALLBACK (toolbar_reconfigured_cb), action);
+		g_signal_connect (proxy, "set-tooltip", 
+				  G_CALLBACK (set_tooltip_cb), action);
 
 		button = GTK_WIDGET (g_object_get_data (G_OBJECT (proxy), "button"));
 		g_signal_connect (button, "clicked", G_CALLBACK (activate_cb), action);
@@ -448,6 +499,11 @@ connect_proxy (GtkAction *action, GtkWidget *proxy)
 		entry = GTK_WIDGET (g_object_get_data (G_OBJECT (proxy), "entry"));
 		g_signal_connect (entry, "activate", G_CALLBACK (activate_cb), action);
 		g_signal_connect (entry, "key-press-event", G_CALLBACK (entry_key_press_cb), action);
+
+		g_signal_connect (button, "drag-data-get",
+				  G_CALLBACK (drag_data_get_cb), action);
+		gtk_drag_source_set (button, GDK_BUTTON1_MASK, drag_types,
+				     G_N_ELEMENTS (drag_types), GDK_ACTION_COPY);
 	}
 	else if (GTK_IS_MENU_ITEM (proxy))
 	{
@@ -505,17 +561,20 @@ ephy_bookmark_action_get_bookmark (EphyBookmarkAction *action)
 void
 ephy_bookmark_action_set_bookmark (EphyBookmarkAction *action,
 				   EphyNode *node)
-{        
+{
+	EphyBookmarkActionPrivate *priv = action->priv;
+	GObject *object = G_OBJECT (action);
+
 	g_return_if_fail (node != NULL);
-	
-	action->priv->node = node;
-	
-	g_object_freeze_notify (G_OBJECT (action));
-	
-	g_object_notify (G_OBJECT (action), "bookmark");
+
+	priv->node = node;
+
+	g_object_freeze_notify (object);
+
+	g_object_notify (object, "bookmark");
 	ephy_bookmark_action_updated (action);
-	
-	g_object_thaw_notify (G_OBJECT (action));        
+
+	g_object_thaw_notify (object);
 }
 
 static void
@@ -547,37 +606,57 @@ ephy_bookmark_action_get_property (GObject *object,
 				   GParamSpec *pspec)
 {
 	EphyBookmarkAction *action = EPHY_BOOKMARK_ACTION (object);
+	EphyBookmarkActionPrivate *priv = action->priv;
 
-	g_return_if_fail (action->priv->node != NULL);
+	g_return_if_fail (priv->node != NULL);
 
 	switch (prop_id)
 	{
 		case PROP_BOOKMARK:
-			g_value_set_pointer (value, action->priv->node);
+			g_value_set_pointer (value, priv->node);
 			break;
 		case PROP_TOOLTIP:
 		case PROP_LOCATION:
 			g_value_set_string (value,
-				ephy_node_get_property_string (action->priv->node,
+				ephy_node_get_property_string (priv->node,
 					EPHY_NODE_BMK_PROP_LOCATION));
 			break;
 		case PROP_SMART_URL:
-			g_value_set_boolean (value, action->priv->smart_url);
+			g_value_set_boolean (value, priv->smart_url);
 			break;
 		case PROP_ICON:
 			g_value_set_string (value,
-				ephy_node_get_property_string (action->priv->node,
+				ephy_node_get_property_string (priv->node,
 					EPHY_NODE_BMK_PROP_ICON));
 			break;
 	}
 }
 
 static void
-ephy_bookmark_action_finalize (GObject *object)
+ephy_bookmark_action_init (EphyBookmarkAction *action)
 {
-	LOG ("Bookmark action %p finalized", object);
+	action->priv = EPHY_BOOKMARK_ACTION_GET_PRIVATE (action);
+	
+	action->priv->cache_handler = 0;
+}
 
-	parent_class->finalize (object);
+static void
+ephy_bookmark_action_dispose (GObject *object)
+{
+	EphyBookmarkAction *action = (EphyBookmarkAction *) object;
+	EphyBookmarkActionPrivate *priv = action->priv;
+	GObject *cache;
+
+	if (priv->cache_handler != 0)
+	{
+		cache = ephy_embed_shell_get_favicon_cache
+				(ephy_embed_shell_get_default ());
+
+		g_signal_handler_disconnect (cache, priv->cache_handler);
+		priv->cache_handler = 0;
+	}
+
+	parent_class->dispose (object);
 }
 
 static void
@@ -593,15 +672,15 @@ ephy_bookmark_action_class_init (EphyBookmarkActionClass *class)
 	action_class->menu_item_type = GTK_TYPE_IMAGE_MENU_ITEM;
 	action_class->connect_proxy = connect_proxy;
 
-	object_class->finalize = ephy_bookmark_action_finalize;
+	object_class->dispose = ephy_bookmark_action_dispose;
 	object_class->set_property = ephy_bookmark_action_set_property;
 	object_class->get_property = ephy_bookmark_action_get_property;
 
 	g_object_class_install_property (object_class,
 					 PROP_BOOKMARK,
 					 g_param_spec_pointer ("bookmark",
-							       "Bookmark",
-							       "Bookmark",
+							       "bookmark",
+							       "bookmark",
 							       G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB |
 							       G_PARAM_CONSTRUCT_ONLY));
 
@@ -609,61 +688,72 @@ ephy_bookmark_action_class_init (EphyBookmarkActionClass *class)
 	g_object_class_install_property (object_class,
 					 PROP_TOOLTIP,
 					 g_param_spec_string  ("tooltip",
-							       "Tooltip",
-							       "Tooltip",
+							       "tooltip",
+							       "tooltip",
 							       NULL,
 							       G_PARAM_READABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 	
 	g_object_class_install_property (object_class,
 					 PROP_LOCATION,
 					 g_param_spec_string  ("location",
-							       "Location",
-							       "Location",
+							       "location",
+							       "location",
 							       NULL,
 							       G_PARAM_READABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 	g_object_class_install_property (object_class,
 					 PROP_SMART_URL,
 					 g_param_spec_boolean  ("smarturl",
-								"Smart url",
-								"Smart url",
+								"smarturl",
+								"smarturl",
 								FALSE,
 								G_PARAM_READABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 	g_object_class_install_property (object_class,
 					 PROP_ICON,
 					 g_param_spec_string  ("icon",
-							       "Icon",
-							       "Icon",
+							       "icon",
+							       "icon",
 							       NULL,
 							       G_PARAM_READABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
 	g_type_class_add_private (object_class, sizeof(EphyBookmarkActionPrivate));
 }
 
-static void
-ephy_bookmark_action_init (EphyBookmarkAction *action)
+GType
+ephy_bookmark_action_get_type (void)
 {
-	action->priv = EPHY_BOOKMARK_ACTION_GET_PRIVATE (action);
-	action->priv->cache_handler = 0;
-}
+	static GType type = 0;
 
-char *
-ephy_bookmark_action_name (EphyNode *node)
-{
-	return g_strdup_printf("Bmk%u", ephy_node_get_id (node));
+	if (G_UNLIKELY (type == 0))
+	{
+		static const GTypeInfo type_info =
+		{
+			sizeof (EphyBookmarkActionClass),
+			(GBaseInitFunc) NULL,
+			(GBaseFinalizeFunc) NULL,
+			(GClassInitFunc) ephy_bookmark_action_class_init,
+			(GClassFinalizeFunc) NULL,
+			NULL,
+			sizeof (EphyBookmarkAction),
+			0, /* n_preallocs */
+			(GInstanceInitFunc) ephy_bookmark_action_init,
+		};
+
+		type = g_type_register_static (EPHY_TYPE_LINK_ACTION,
+					       "EphyBookmarkAction",
+					       &type_info, 0);
+	}
+
+	return type;
 }
 
 GtkAction *
-ephy_bookmark_action_new (EphyNode *node, char *name)
+ephy_bookmark_action_new (EphyNode *node,
+			  const char *name)
 {
-	GtkAction *action;
-	
-	if(!name) name = ephy_bookmark_action_name (node);
-	g_return_val_if_fail (name, NULL);
-	
-	action =  GTK_ACTION (g_object_new (EPHY_TYPE_BOOKMARK_ACTION,
-					    "name", name,
-					    "bookmark", node,
-					    NULL));
+	g_assert (name != NULL);
 
-	return action;
+	return  GTK_ACTION (g_object_new (EPHY_TYPE_BOOKMARK_ACTION,
+					  "name", name,
+					  "bookmark", node,
+					  NULL));
 }
