@@ -16,12 +16,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-encoding-dialog.c,v 1.18 2004/10/27 19:54:57 chpe Exp $
+ *  $Id: ephy-encoding-dialog.c,v 1.23 2005/12/31 19:12:31 crispin Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-encoding-dialog.h"
 #include "ephy-encodings.h"
@@ -45,6 +43,7 @@
 
 enum
 {
+	WINDOW_PROP,
 	SCROLLED_WINDOW_PROP,
 	AUTOMATIC_PROP,
 	MANUAL_PROP
@@ -53,6 +52,7 @@ enum
 static const
 EphyDialogProperty properties [] =
 {
+	{ "encoding_dialog",	NULL, PT_NORMAL, 0 },
 	{ "scrolled_window",	NULL, PT_NORMAL, 0 },
 	{ "automatic_button",	NULL, PT_NORMAL, 0 },
 	{ "manual_button",	NULL, PT_NORMAL, 0 },
@@ -62,7 +62,7 @@ EphyDialogProperty properties [] =
 
 #define EPHY_ENCODING_DIALOG_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_ENCODING_DIALOG, EphyEncodingDialogPrivate))
 
-struct EphyEncodingDialogPrivate
+struct _EphyEncodingDialogPrivate
 {
 	EphyEncodings *encodings;
 	EphyWindow *window;
@@ -75,9 +75,6 @@ struct EphyEncodingDialogPrivate
 
 static void	ephy_encoding_dialog_class_init		(EphyEncodingDialogClass *klass);
 static void	ephy_encoding_dialog_init		(EphyEncodingDialog *ge);
-void		ephy_encoding_dialog_response_cb	(GtkWidget *widget,
-							 int response,
-							 EphyEncodingDialog *dialog);
 
 static GObjectClass *parent_class = NULL;
 
@@ -110,7 +107,7 @@ ephy_encoding_dialog_get_type (void)
 }
 
 static void
-sync_embed_cb (EphyEncodingDialog *dialog, GParamSpec *pspec, gpointer dummy)
+sync_encoding_against_embed (EphyEncodingDialog *dialog)
 {
 	EphyEmbed *embed;
 	EphyNode *node;
@@ -163,6 +160,33 @@ sync_embed_cb (EphyEncodingDialog *dialog, GParamSpec *pspec, gpointer dummy)
 	dialog->priv->update_tag = FALSE;
 }
 
+
+static void
+embed_net_stop_cb (EphyEmbed *embed, EphyEncodingDialog *dialog)
+{
+	sync_encoding_against_embed (dialog);
+}
+
+static void
+sync_embed_cb (EphyEncodingDialog *dialog, GParamSpec *pspec, gpointer dummy)
+{
+	EphyEmbed *embed;
+	embed = ephy_embed_dialog_get_embed (EPHY_EMBED_DIALOG (dialog));
+
+	if (dialog->priv->embed != NULL)
+	{
+		g_signal_handlers_disconnect_by_func (dialog->priv->embed,
+						      G_CALLBACK (embed_net_stop_cb),
+						      dialog);
+	}
+
+	g_signal_connect (G_OBJECT (embed), "net_stop",
+			  G_CALLBACK (embed_net_stop_cb), dialog);
+	dialog->priv->embed = embed;
+
+	sync_encoding_against_embed (dialog);
+}
+
 static void
 sync_active_tab (EphyWindow *window, GParamSpec *pspec, EphyEncodingDialog *dialog)
 {
@@ -225,7 +249,7 @@ activate_choice (EphyEncodingDialog *dialog)
 	}
 }
 
-void
+static void
 ephy_encoding_dialog_response_cb (GtkWidget *widget,
 				  int response,
 				  EphyEncodingDialog *dialog)
@@ -288,7 +312,7 @@ automatic_toggled_cb (GtkToggleButton *button, EphyEncodingDialog *dialog)
 static void
 ephy_encoding_dialog_init (EphyEncodingDialog *dialog)
 {
-	GtkWidget *treeview, *scroller, *button;
+	GtkWidget *treeview, *scroller, *button, *window;
 	GtkTreeSelection *selection;
 	EphyNode *node;
 
@@ -304,6 +328,10 @@ ephy_encoding_dialog_init (EphyEncodingDialog *dialog)
 			       "encoding_dialog",
 			       NULL);
 
+	window = ephy_dialog_get_control (EPHY_DIALOG (dialog), properties[WINDOW_PROP].id);
+	g_signal_connect (window, "response",
+			  G_CALLBACK (ephy_encoding_dialog_response_cb), dialog);
+
 	dialog->priv->filter = ephy_node_filter_new ();
 
 	node = ephy_encodings_get_all (dialog->priv->encodings);
@@ -313,7 +341,7 @@ ephy_encoding_dialog_init (EphyEncodingDialog *dialog)
 				   G_TYPE_STRING,
 				   EPHY_NODE_ENCODING_PROP_TITLE_ELIDED,
 				   EPHY_NODE_VIEW_SEARCHABLE,
-				   NULL);
+				   NULL, NULL);
 
 	ephy_node_view_set_sort (EPHY_NODE_VIEW (treeview), G_TYPE_STRING,
 				 EPHY_NODE_ENCODING_PROP_TITLE_ELIDED,
@@ -366,6 +394,13 @@ ephy_encoding_dialog_finalize (GObject *object)
 						      dialog);
 	}
 
+	if (dialog->priv->embed)
+	{
+		g_signal_handlers_disconnect_by_func (dialog->priv->embed,
+						      G_CALLBACK (embed_net_stop_cb),
+						      dialog);
+	}
+
 	g_object_unref (dialog->priv->filter);
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
