@@ -16,12 +16,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-go-action.c,v 1.10 2004/10/23 16:49:10 chpe Exp $
+ *  $Id: ephy-go-action.c,v 1.13 2006/01/29 21:47:21 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-go-action.h"
 #include "ephy-debug.h"
@@ -54,7 +52,7 @@ ephy_go_action_get_type (void)
 			(GInstanceInitFunc) NULL,
 		};
 
-		type = g_type_register_static (GTK_TYPE_ACTION,
+		type = g_type_register_static (EPHY_TYPE_LINK_ACTION,
 					       "EphyGoAction",
 					       &type_info, 0);
 	}
@@ -72,6 +70,7 @@ create_tool_item (GtkAction *action)
 
 	button = gtk_button_new_with_label (_("Go"));
 	gtk_button_set_relief(GTK_BUTTON (button), GTK_RELIEF_NONE);
+	gtk_button_set_focus_on_click (GTK_BUTTON (button), FALSE);
 
 	gtk_container_add (GTK_CONTAINER (item), button);
 	gtk_widget_show (button);
