@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-main.c,v 1.63 2006/03/02 21:30:04 chpe Exp $
+ *  $Id: ephy-main.c,v 1.67 2006/07/23 16:53:18 chpe Exp $
  */
 
 #include "config.h"
@@ -86,36 +86,15 @@ static const GOptionEntry option_entries[] =
 	  N_("Load the given session file"), N_("FILE") },
 	{ "add-bookmark", 't', 0, G_OPTION_ARG_STRING, &bookmark_url,
 	  N_("Add a bookmark"), N_("URL") },
-	{ "private-instance", 0, 0, G_OPTION_ARG_NONE, &private_instance,
+	{ "private-instance", 'p', 0, G_OPTION_ARG_NONE, &private_instance,
 	  N_("Start a private instance"), NULL },
 	{ "profile", 0, 0, G_OPTION_ARG_STRING, &profile_directory,
 	  N_("Profile directory to use in the private instance"), N_("DIR") },
 	{ G_OPTION_REMAINING, '\0', 0, G_OPTION_ARG_FILENAME_ARRAY, &arguments,
-	  "", "" },
+	  "", N_("URL ...")},
 	{ NULL }
 };
 
-#ifndef GNOME_PARAM_GOPTION_CONTEXT
-/* libgnome < 2.13 compat */
-static char *sm_client_id = NULL;
-static char *sm_config_prefix = NULL;
-static gboolean sm_disable = FALSE;
-static gboolean disable_crash_dialog = FALSE;
-
-static const GOptionEntry libgnome_option_entries[] =
-{
-	{ "sm-client-id", 0, 0, G_OPTION_ARG_STRING, &sm_client_id,
-	  "Specify session management ID", "ID" },
-	{ "sm-config-prefix", 0, 0, G_OPTION_ARG_STRING, &sm_config_prefix,
-	  "Specify prefix of saved configuration", "PREFIX" },
-	{ "sm-disable", 0, 0, G_OPTION_ARG_NONE, &sm_disable,
-	  "Disable connection to session manager", NULL },
-	{ "disable-crash-dialog", 0, 0, G_OPTION_ARG_NONE, &disable_crash_dialog,
-	  "Disable Crash Dialog", NULL },
-	{ NULL }
-};
-#endif /* !GNOME_PARAM_GOPTION_CONTEXT */
-
 #ifdef GNOME_ENABLE_DEBUG
 static GOptionEntry debug_option_entries[] =
 {
@@ -429,12 +408,14 @@ int
 main (int argc,
       char *argv[])
 {
+	GnomeProgram *program;
 	GOptionContext *option_context;
 	GOptionGroup *option_group;
 	DBusGProxy *proxy;
 	GError *error = NULL;
 	guint32 user_time;
 	const char *env;
+	gboolean enable_pango;
 #ifndef GNOME_PARAM_GOPTION_CONTEXT
 	GPtrArray *fake_argv_array;
 #endif
@@ -514,7 +495,7 @@ main (int argc,
 	/* get this early, since gdk will unset the env var */
 	user_time = get_startup_id ();
 
-	option_context = g_option_context_new (_("GNOME Web Browser"));
+	option_context = g_option_context_new ("");
 	option_group = g_option_group_new ("epiphany",
 					   N_("GNOME Web Browser"),
 					   N_("GNOME Web Browser options"),
@@ -532,72 +513,17 @@ main (int argc,
 	g_option_context_add_group (option_context, option_group);
 #endif /* GNOME_ENABLE_DEBUG */
 
-#ifdef GNOME_PARAM_GOPTION_CONTEXT
-	gnome_program_init (PACKAGE, VERSION,
-			    LIBGNOMEUI_MODULE, argc, argv,
-			    GNOME_PARAM_GOPTION_CONTEXT, option_context,
-			    GNOME_PARAM_HUMAN_READABLE_NAME, _("Web Browser"),
-			    GNOME_PARAM_APP_DATADIR, DATADIR,
-			    NULL);
+	program = gnome_program_init (PACKAGE, VERSION,
+				      LIBGNOMEUI_MODULE, argc, argv,
+				      GNOME_PARAM_GOPTION_CONTEXT, option_context,
+				      GNOME_PARAM_HUMAN_READABLE_NAME, _("Web Browser"),
+				      GNOME_PARAM_APP_DATADIR, DATADIR,
+				      NULL);
 
-#else /* !GNOME_PARAM_GOPTION_CONTEXT */
-
-	option_group = g_option_group_new ("gnome-compat", "GNOME GUI Library",
-					   "Show GNOME GUI options", NULL, NULL);
-	g_option_group_set_translation_domain (option_group, "libgnomeui-2.0");
-	g_option_group_add_entries (option_group, libgnome_option_entries);
-	g_option_context_add_group (option_context, option_group);
-
-	/* Add the gtk+ option group, but don't open the default display! */
-	option_group = gtk_get_option_group (FALSE);
-	g_option_context_add_group (option_context, option_group);
-
-	if (!g_option_context_parse (option_context, &argc, &argv, &error))
-	{
-		g_option_context_free (option_context);
-
-		g_print ("%s\n", error->message);
-		g_error_free (error);
-		exit (1);
-	}
-
-	fake_argv_array = g_ptr_array_new ();
-	
-	g_ptr_array_add (fake_argv_array, g_strdup (g_get_prgname ()));
-	if (sm_disable)
-	{
-		g_ptr_array_add (fake_argv_array, g_strdup ("--sm-disable"));
-	}
-	if (sm_client_id != NULL)
-	{
-		g_ptr_array_add (fake_argv_array, g_strdup ("--sm-client-id"));
-		g_ptr_array_add (fake_argv_array, sm_client_id);
-	}
-	if (sm_config_prefix != NULL)
-	{
-		g_ptr_array_add (fake_argv_array, g_strdup ("--sm-config-prefix"));
-		g_ptr_array_add (fake_argv_array, sm_config_prefix);
-	}
-	if (disable_crash_dialog)
-	{
-		g_ptr_array_add (fake_argv_array, g_strdup ("--disable-crash-dialog"));
-	}
-
-	gnome_program_init (PACKAGE, VERSION,
-			    LIBGNOMEUI_MODULE,
-			    fake_argv_array->len,
-			    (char**) fake_argv_array->pdata,
-			    GNOME_PARAM_HUMAN_READABLE_NAME, _("Web Browser"),
-			    GNOME_PARAM_APP_DATADIR, DATADIR,
-			    NULL);
-
-	g_ptr_array_add (fake_argv_array, NULL);
-	g_strfreev ((char**) g_ptr_array_free (fake_argv_array, FALSE));
-
-	g_option_context_free (option_context);
-	option_context = NULL;
-
-#endif /* GNOME_PARAM_GOPTION_CONTEXT */
+	/* libgnome keeps a reference to the global program, so drop
+	 * our reference here, to simplify cleanup on the many exit paths.
+	 */
+	g_object_unref (program);
 
 	/* Some argument sanity checks*/
 	if (arguments != NULL && (session_filename != NULL || open_as_bookmarks_editor))
@@ -734,6 +660,7 @@ main (int argc,
 		_ephy_dbus_release ();
 
 		gdk_notify_startup_complete ();
+
 		exit (0);
 	}
 
@@ -752,22 +679,31 @@ main (int argc,
 	}
 
 	eel_gconf_monitor_add ("/apps/epiphany/general");
-	gnome_vfs_init ();
 	ephy_stock_icons_init ();
 
 	/* Extensions may want these, so don't initialize in window-cmds */
 	gtk_about_dialog_set_url_hook (handle_url, NULL, NULL);
 	gtk_about_dialog_set_email_hook (handle_email, NULL, NULL);
 
-	/* Work around bug #328844 */
+	/* Work around bug #328844, and avoid the gecko+pango performance problem */
 	env = g_getenv ("MOZ_ENABLE_PANGO");
-	if (env == NULL ||
-	    env[0] == '\0' ||
-	    strcmp (env, "0") == 0)
+	enable_pango = env != NULL &&
+		       env[0] != '\0' &&
+		       g_ascii_strtoull (env, NULL, 10) != 0;
+
+	if (eel_gconf_get_boolean (CONF_GECKO_ENABLE_PANGO))
+	{
+		g_print ("NOTE: Enabling gecko pango renderer; this may cause performance degradation.\n"
+			 "You can set " CONF_GECKO_ENABLE_PANGO " to \"false\" to disable it.\n");
+	}
+	else if (!enable_pango)
 	{
 		g_setenv ("MOZ_DISABLE_PANGO", "1", TRUE);
 	}
 
+	/* Work-around Flash Player crash */
+	g_setenv ("XLIB_SKIP_ARGB_VISUALS", "1", FALSE);
+
 	/* Now create the shell */
 	_ephy_shell_create_instance ();
 
