@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-navigation-action.c,v 1.28 2005/10/16 18:59:45 philipl Exp $
+ *  $Id: ephy-navigation-action.c,v 1.29 2005/11/08 12:46:43 chpe Exp $
  */
 
 #include "config.h"
@@ -527,7 +527,7 @@ ephy_navigation_action_class_init (EphyNavigationActionClass *class)
 							      "Arrow Tooltip",
 							      "Arrow Tooltip",
 							      NULL,
-							      G_PARAM_READWRITE));
+							      G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
 	g_object_class_install_property (object_class,
 					 PROP_DIRECTION,
@@ -537,14 +537,14 @@ ephy_navigation_action_class_init (EphyNavigationActionClass *class)
 							   0,
 							   G_MAXINT,
 							   0,
-							   G_PARAM_READWRITE));
+							   G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 	g_object_class_install_property (object_class,
 					 PROP_WINDOW,
 					 g_param_spec_object ("window",
 							      "Window",
 							      "The navigation window",
 							      G_TYPE_OBJECT,
-							      G_PARAM_READWRITE));
+							      G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
 	g_type_class_add_private (object_class, sizeof (EphyNavigationActionPrivate));
 }
