@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-statusbar.h,v 1.9 2006/01/18 14:21:11 chpe Exp $
+ *  $Id: ephy-statusbar.h,v 1.10 2006/07/24 19:34:54 chpe Exp $
  */
 
 #ifndef EPHY_STATUSBAR_H
@@ -55,6 +55,9 @@ struct _EphyStatusbar
 struct _EphyStatusbarClass
 {
         GtkStatusbarClass parent_class;
+
+	/* Signals */
+	void (* lock_clicked)	(EphyStatusbar *statusbar);
 };
 
 GType         ephy_statusbar_get_type			(void);
