@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: window-commands.c,v 1.195 2006/07/06 20:53:54 chpe Exp $
+ *  $Id: window-commands.c,v 1.197 2006/08/07 20:42:44 chpe Exp $
  */
 
 #include "config.h"
@@ -463,6 +463,28 @@ window_cmd_edit_paste (GtkAction *action,
 	}
 }
 
+void
+window_cmd_edit_delete (GtkAction *action,
+			EphyWindow *window)
+{
+	GtkWidget *widget = gtk_window_get_focus (GTK_WINDOW (window));
+
+	if (GTK_IS_EDITABLE (widget))
+	{
+		gtk_editable_delete_text (GTK_EDITABLE (widget), 0, -1);
+	}
+	else
+	{
+		EphyEmbed *embed;
+
+		embed = ephy_window_get_active_embed (window);
+		g_return_if_fail (embed != NULL);
+
+		ephy_command_manager_do_command (EPHY_COMMAND_MANAGER (embed),
+						 "cmd_delete");
+	}
+}
+
 void
 window_cmd_edit_select_all (GtkAction *action,
 			    EphyWindow *window)
@@ -636,6 +658,18 @@ window_cmd_view_page_source (GtkAction *action,
 	}
 }
 
+void
+window_cmd_view_page_security_info (GtkAction *action,
+				    EphyWindow *window)
+{
+	EphyEmbed *embed;
+
+	embed = ephy_window_get_active_embed (window);
+	g_return_if_fail (EPHY_IS_EMBED (embed));
+
+	ephy_embed_show_page_certificate (embed);
+}
+
 void
 window_cmd_go_history (GtkAction *action,
 		       EphyWindow *window)
@@ -720,8 +754,6 @@ window_cmd_help_about (GtkAction *action,
 		       GtkWidget *window)
 {
 	const char * const authors[] = {
-		"Marco Pesenti Gritti",
-		"Adam Hooper",
 		"Xan Lopez",
 		"Christian Persch",
 		"Jean-François Rameau",
@@ -735,7 +767,9 @@ window_cmd_help_about (GtkAction *action,
 		"Raphaël Slinckx",
 		"",
 		_("Past developers:"),
+		"Marco Pesenti Gritti",
 		"David Bordoley",
+		"Adam Hooper",
 		NULL,
 	};
 	const char * const documenters[] = {
